﻿using KTour.Common;
using KTour.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace KTour.OpenAPI
{
    public class CategoryService : BaseService<CodeModel>
    {
        /// <summary>
        /// 생성자
        /// </summary>
        public CategoryService()
        {
            ServiceUri = "http://api.visitkorea.or.kr/openapi/service/rest/KorService/categoryCode?ServiceKey={0}&MobileOS={1}&MobileApp={2}&numOfRows={3}&cat1={4}&cat2={5}";
        }

        /// <summary>
        /// 조회
        /// </summary>
        /// <param name="cate">카테1|카테2</param>
        /// <returns></returns>
        public override async Task Send(string cate)
        {
            using (HttpClient hc = new HttpClient())
            {
                try
                {
                    var cates = cate.Split('|');
                    var cate1 = cates.Count() >= 1 ? cates[0] : "";
                    var cate2 = cates.Count() >= 2 ? cates[1] : "";
                    var uri = string.Format(ServiceUri, Functions.ApiKey, Functions.MobileOS, Functions.MobileApp, NumOfRows, cate1, cate2);
                    var result = await hc.GetStringAsync(uri);
                    if (!string.IsNullOrEmpty(result))
                    {
                        XElement xml = XElement.Parse(result);

                        var header = xml.Element("header");
                        ResultCode = Functions.GetInt(header.Element("resultCode")).ToString();
                        ResultMsg = Functions.GetString(header.Element("resultMsg"));
                        var body = xml.Element("body");
                        PageNo = Functions.GetInt(body.Element("pageNo"));
                        TotalCount = Functions.GetInt(body.Element("totalCount"));

                        switch (ResultCode)
                        { 
                            case "0":   //정상
                                var rows = from kkk in xml.Descendants("item")
                                           select new CodeModel
                                           {
                                               ParentCode = cates.Count() == 1 ? cate1 : cates.Count() == 2 ? cate2 : "",
                                               Code = Functions.GetString(kkk.Element("code")),
                                               Name = Functions.GetString(kkk.Element("name")),
                                               ValueInt = Functions.GetInt(kkk.Element("rnum")),
                                               ValueString = "CategoryCode"
                                           };
                                ResultCollection = new ObservableCollection<CodeModel>(rows);
                                break;
                            case "22":  //서비스 요청제한횟수 초과에러
                                break;
                            default:
                                Functions.MsgBox("조회 중 오류가 발생했습니다.\n" + ResultMsg);
                                ResultCollection.Clear();
                                break;
                        }

                    }
                }
                catch (Exception ex)
                {
                    Functions.MsgBox("오류" + ex.Message);
                }
            }
        }
    }
}
